/**
 * @function fromFiles
 */

'use strict'

const fs = require('fs')
const path = require('path')
const extend = require('extend')
const arrayfilter = require('arrayfilter')
const sortProperties = require('fmtjson/sort_properties')
const defineLocale = require('./define_locale')

/** @lends fromFiles */
function fromFiles (dirname, buildin) {
  let result = {}

  fs.readdirSync(dirname)
    .filter(arrayfilter.patternReject(/^index\./))
    .filter(arrayfilter.patternReject(/^\./))
    .filter(arrayfilter.patternReject(/^_/))
    .map((filename) => path.resolve(dirname, filename))
    .forEach((filename) => {
      let lang = path.basename(filename, path.extname(filename))
      let fileContent = JSON.parse(fs.readFileSync(filename).toString().trim() || '{}')
      let src = sortProperties(
        extend(true, {}, buildin && buildin[ lang ], fileContent, {
          $lang: lang
        })
      )
      result[ lang ] = defineLocale(src)
    })
  return result
}

module.exports = fromFiles
