/**
 * Print locales settings.
 * @function print
 * @param {object} locales - locales settings to print.
 */

'use strict'

const colorprint = require('colorprint')
const yaml = require('js-yaml')

function _normalize (data) {
  switch (typeof data) {
    case 'number':
    case 'string':
    case 'boolean':
    case 'undefined':
      return data
    default:
      let values = {}
      for (let key of Object.keys(data)) {
        let value = _normalize(data[ key ])
        if (typeof value === 'undefined') {
          continue
        }
        values[ key ] = value
      }
      let isEmpty = Object.keys(values).length === 0
      if (isEmpty) {
        return undefined
      }
      return values
  }
}

/** @lends print */
function print (locales) {
  let values = _normalize(locales)
  colorprint.debug('')
  colorprint.debug('Locale Settings')
  colorprint.debug('------------')
  let msg = yaml.safeDump(values)
  colorprint.debug(colorprint.colors.blackBright(msg))
  colorprint.debug('')
  colorprint.debug('')
}

module.exports = print
