/**
 * Validate lang settings.
 * @function validate
 */
'use strict'

const objnest = require('objnest')
const colorprint = require('colorprint')

/** @lends validate */
function validate (locales) {
  let keySupports = validate._keySupports(locales)
  for (let lang of Object.keys(locales)) {
    for (let key of Object.keys(keySupports)) {
      let supportedLangs = keySupports[ key ]
      let missing = !~supportedLangs.indexOf(lang)
      if (missing) {
        colorprint.warn(`[apemanlocale] WARNING: ${key} is missing in ${lang} locale.`)
      }
    }
  }
}

Object.assign(validate, {
  _keySupports (locales) {
    let supports = {}
    for (let lang of Object.keys(locales)) {
      let locale = locales[ lang ]
      let flattenLocale = objnest.flatten(locale)
      for (let key of Object.keys(flattenLocale)) {
        let supportable = validate._isSupportable(flattenLocale[ key ])
        if (supportable) {
          supports[ key ] = (supports[ key ] || []).concat(lang)
        }
      }
    }
    return supports
  },
  _isSupportable (value) {
    switch (typeof value) {
      case 'undefined':
        return false
      case 'object':
      case 'function':
        return Object.keys(value).length > 0
      default:
        return true
    }
  }
})
module.exports = validate
