/**
 * Test case for apemanlocale.
 * Runs with mocha.
 */
'use strict'

const apemanlocale = require('../lib/apemanlocale.js')
const assert = require('assert')

describe('apemanlocale', () => {
  it('Apemanlocale', (done) => {
    let locales = apemanlocale(`${__dirname}/../doc/mocks/mock-locales`, {
      buildin: true
    })
    assert.equal(locales.ja.titles.FOO, 'これはFooです。')
    assert.equal(locales('ja').titles.FOO, 'これはFooです。')
    assert.equal(locales.en.titles.BAR, 'This is Bar.')
    assert.equal(locales('en').titles.BAR, 'This is Bar.')
    assert.equal(locales('en')('titles.BAR'), 'This is Bar.')
    assert.equal(locales('en').titles.WELCOME_TITLE, 'Welcome to hello-world!')
    assert.equal(locales('en')('titles.WELCOME_TITLE'), 'Welcome to hello-world!')
    assert.deepEqual(locales.langs, [ 'en', 'ja' ])

    let en = locales('en').toJSON()
    assert.ok(en)
    assert.equal(typeof en, 'object')
    locales.validate()
    locales.print()

    assert.ok(locales.toJSON())
    done()
  })
  it('Embed vars', (done) => {
    let locales = apemanlocale(`${__dirname}/../doc/mocks/mock-locales`, {
      buildin: true,
      fallback: true
    })
    let l = locales('en')
    let msg = l('titles.DYNAMIC_TITLE', {
      vars: {
        foo: 'FOO',
        bar: 'BAR',
        baz: 'BAZ'
      }
    })
    assert.equal(msg, 'This is dynamic with FOO with BAR on BAZ')
    done()
  })
})

/* global describe, it */
